#
# spec file for package xev
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xev
Version:        1.2.6
Release:        1.5
Summary:        Utility to print contents of X events
License:        X11
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Patch0:         u_Add-event-filter-for-motion-and-button-events.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xrandr) >= 1.2
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xev creates a window and then asks the X server to send it X11 events
whenever anything happens to the window (such as it being moved,
resized, typed in, clicked in, etc.). You can also attach it to an
existing window. It is useful for seeing what causes events to occur
and to display the information that they contain; it is essentially a
debugging and development tool, and should not be needed in normal
usage.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xev
%{_mandir}/man1/xev.1%{?ext_man}

%changelog
* Mon Mar  4 2024 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.2.6
  * gitlab CI: stop requiring Signed-off-by in commits
  * Mark global variables as "static" since there's only one source file
  * Mark graceful_exit as noreturn
  * Fix overflow on XmbLookupString buffer
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Thu Aug 11 2022 Dirk Müller <dmueller@suse.com>
- modernize spec-file, move license to %%%%licensedir
* Tue Jul 12 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.5
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * man page: remove out-of-date reference to X(7)
  * xev: fix KeymapNotify event printing
* Sat Jul 18 2020 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.2.4
  * Add option "-1" to display only a single line per event
- refreshed u_Add-event-filter-for-motion-and-button-events.patch
* Wed Feb 20 2019 sndirsch@suse.com
- update to version 1.2.3
  * bugfixes
- adjusted u_Add-event-filter-for-motion-and-button-events.patch
* Sat Apr 18 2015 benoit.monin@gmx.fr
- update to version 1.2.2:
  * autogen.sh: Honor NOCONFIGURE=1
  * configure: Drop AM_MAINTAINER_MODE
  * Add event filter for button events
  * Add -version option to print program version
  * Print which option was in error along with usage message
  * man: Add -event to the command synopsis
- add tarball signature and keyring
- refresh u_Add-event-filter-for-motion-and-button-events.patch:
  partially merged upstream
* Tue Feb 11 2014 eich@suse.com
- u_Add-event-filter-for-motion-and-button-events.patch
  Add more event filters
* Thu Feb  6 2014 sndirsch@suse.com
- fixed license to X11 in specfile
* Mon Feb  4 2013 sndirsch@suse.com
- Update to version 1.2.1
  * This release adds a "-event" option that can be used to filter
    which events are printed. For example, to listen only for RandR
    events, use "xev -event randr". The -event parameter can be
    specified multiple times.  Please see the manual page for the
    list of available event filters.
  * This release also contains a few code fixes.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.2.0:
  + Show RandR events
  + Build system fixes
- Add pkgconfig(xproto) and pkgconfig(xrandr) BuildRequires.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xev from xorg-x11. Initial version: 1.1.0.
